#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-variable-editor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-variable-editor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-variable-editor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6octave20variable_dock_widgetE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::variable_dock_widget::qt_create_metaobjectdata<qt_meta_tag_ZN6octave20variable_dock_widgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::variable_dock_widget",
        "variable_focused_signal",
        "",
        "name",
        "queue_unfloat_float",
        "queue_float",
        "handle_focus_change",
        "QWidget*",
        "old",
        "now",
        "change_floating",
        "change_existence",
        "toplevel_change",
        "change_fullscreen",
        "unfloat_float",
        "refloat"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'variable_focused_signal'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'queue_unfloat_float'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queue_float'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_focus_change'
        QtMocHelpers::SlotData<void(QWidget *, QWidget *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
        // Slot 'change_floating'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'change_existence'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toplevel_change'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'change_fullscreen'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unfloat_float'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'refloat'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<variable_dock_widget, qt_meta_tag_ZN6octave20variable_dock_widgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::variable_dock_widget::staticMetaObject = { {
    QMetaObject::SuperData::link<label_dock_widget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20variable_dock_widgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20variable_dock_widgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave20variable_dock_widgetE_t>.metaTypes,
    nullptr
} };

void octave::variable_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<variable_dock_widget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->variable_focused_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->queue_unfloat_float(); break;
        case 2: _t->queue_float(); break;
        case 3: _t->handle_focus_change((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 4: _t->change_floating((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->change_existence((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->toplevel_change((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->change_fullscreen(); break;
        case 8: _t->unfloat_float(); break;
        case 9: _t->refloat(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (variable_dock_widget::*)(const QString & )>(_a, &variable_dock_widget::variable_focused_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_dock_widget::*)()>(_a, &variable_dock_widget::queue_unfloat_float, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_dock_widget::*)()>(_a, &variable_dock_widget::queue_float, 2))
            return;
    }
}

const QMetaObject *octave::variable_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20variable_dock_widgetE_t>.strings))
        return static_cast<void*>(this);
    return label_dock_widget::qt_metacast(_clname);
}

int octave::variable_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = label_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_dock_widget::variable_focused_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void octave::variable_dock_widget::queue_unfloat_float()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void octave::variable_dock_widget::queue_float()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN6octave21variable_editor_stackE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::variable_editor_stack::qt_create_metaobjectdata<qt_meta_tag_ZN6octave21variable_editor_stackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::variable_editor_stack",
        "edit_variable_signal",
        "",
        "name",
        "octave_value",
        "val",
        "do_save_signal",
        "format",
        "save_opts",
        "interpreter_event",
        "fcn_callback",
        "fcn",
        "meth_callback",
        "meth",
        "set_editable",
        "editable",
        "levelUp",
        "save",
        "do_save"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'edit_variable_signal'
        QtMocHelpers::SignalData<void(const QString &, const octave_value &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'do_save_signal'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const fcn_callback &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const meth_callback &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'set_editable'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'levelUp'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'do_save'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<variable_editor_stack, qt_meta_tag_ZN6octave21variable_editor_stackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::variable_editor_stack::staticMetaObject = { {
    QMetaObject::SuperData::link<QStackedWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave21variable_editor_stackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave21variable_editor_stackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave21variable_editor_stackE_t>.metaTypes,
    nullptr
} };

void octave::variable_editor_stack::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<variable_editor_stack *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->edit_variable_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<octave_value>>(_a[2]))); break;
        case 1: _t->do_save_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
        case 3: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
        case 4: _t->set_editable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->levelUp(); break;
        case 6: _t->save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->save(); break;
        case 8: _t->do_save((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (variable_editor_stack::*)(const QString & , const octave_value & )>(_a, &variable_editor_stack::edit_variable_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor_stack::*)(const QString & , const QString & )>(_a, &variable_editor_stack::do_save_signal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor_stack::*)(const fcn_callback & )>(_a, &variable_editor_stack::interpreter_event, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor_stack::*)(const meth_callback & )>(_a, &variable_editor_stack::interpreter_event, 3))
            return;
    }
}

const QMetaObject *octave::variable_editor_stack::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_editor_stack::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave21variable_editor_stackE_t>.strings))
        return static_cast<void*>(this);
    return QStackedWidget::qt_metacast(_clname);
}

int octave::variable_editor_stack::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStackedWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_editor_stack::edit_variable_signal(const QString & _t1, const octave_value & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void octave::variable_editor_stack::do_save_signal(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void octave::variable_editor_stack::interpreter_event(const fcn_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void octave::variable_editor_stack::interpreter_event(const meth_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN6octave20variable_editor_viewE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::variable_editor_view::qt_create_metaobjectdata<qt_meta_tag_ZN6octave20variable_editor_viewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::variable_editor_view",
        "command_signal",
        "",
        "cmd",
        "add_edit_actions_signal",
        "QMenu*",
        "menu",
        "qualifier_string",
        "createVariable",
        "transposeContent",
        "range_selected",
        "QList<int>",
        "delete_selected",
        "clearContent",
        "cutClipboard",
        "copyClipboard",
        "pasteClipboard",
        "handle_horizontal_scroll_action",
        "action",
        "handle_vertical_scroll_action",
        "createContextMenu",
        "QPoint",
        "pt",
        "createColumnMenu",
        "createRowMenu",
        "selected_command_requested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'command_signal'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'add_edit_actions_signal'
        QtMocHelpers::SignalData<void(QMenu *, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'createVariable'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'transposeContent'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'range_selected'
        QtMocHelpers::SlotData<QList<int>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'delete_selected'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearContent'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cutClipboard'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyClipboard'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteClipboard'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_horizontal_scroll_action'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'handle_vertical_scroll_action'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'createContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'createColumnMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'createRowMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'selected_command_requested'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<variable_editor_view, qt_meta_tag_ZN6octave20variable_editor_viewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::variable_editor_view::staticMetaObject = { {
    QMetaObject::SuperData::link<QTableView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20variable_editor_viewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20variable_editor_viewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave20variable_editor_viewE_t>.metaTypes,
    nullptr
} };

void octave::variable_editor_view::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<variable_editor_view *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->command_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->add_edit_actions_signal((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->createVariable(); break;
        case 3: _t->transposeContent(); break;
        case 4: { QList<int> _r = _t->range_selected();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->delete_selected(); break;
        case 6: _t->clearContent(); break;
        case 7: _t->cutClipboard(); break;
        case 8: _t->copyClipboard(); break;
        case 9: _t->pasteClipboard(); break;
        case 10: _t->handle_horizontal_scroll_action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->handle_vertical_scroll_action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->createContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 13: _t->createColumnMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 14: _t->createRowMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 15: _t->selected_command_requested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (variable_editor_view::*)(const QString & )>(_a, &variable_editor_view::command_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor_view::*)(QMenu * , const QString & )>(_a, &variable_editor_view::add_edit_actions_signal, 1))
            return;
    }
}

const QMetaObject *octave::variable_editor_view::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_editor_view::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave20variable_editor_viewE_t>.strings))
        return static_cast<void*>(this);
    return QTableView::qt_metacast(_clname);
}

int octave::variable_editor_view::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTableView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_editor_view::command_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void octave::variable_editor_view::add_edit_actions_signal(QMenu * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN6octave15HoverToolButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::HoverToolButton::qt_create_metaobjectdata<qt_meta_tag_ZN6octave15HoverToolButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::HoverToolButton",
        "hovered_signal",
        "",
        "popup_shown_signal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hovered_signal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'popup_shown_signal'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HoverToolButton, qt_meta_tag_ZN6octave15HoverToolButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::HoverToolButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QToolButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15HoverToolButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15HoverToolButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave15HoverToolButtonE_t>.metaTypes,
    nullptr
} };

void octave::HoverToolButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HoverToolButton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hovered_signal(); break;
        case 1: _t->popup_shown_signal(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HoverToolButton::*)()>(_a, &HoverToolButton::hovered_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HoverToolButton::*)()>(_a, &HoverToolButton::popup_shown_signal, 1))
            return;
    }
}

const QMetaObject *octave::HoverToolButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::HoverToolButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15HoverToolButtonE_t>.strings))
        return static_cast<void*>(this);
    return QToolButton::qt_metacast(_clname);
}

int octave::HoverToolButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void octave::HoverToolButton::hovered_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::HoverToolButton::popup_shown_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::ReturnFocusToolButton::qt_create_metaobjectdata<qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::ReturnFocusToolButton",
        "about_to_activate",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'about_to_activate'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReturnFocusToolButton, qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::ReturnFocusToolButton::staticMetaObject = { {
    QMetaObject::SuperData::link<HoverToolButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t>.metaTypes,
    nullptr
} };

void octave::ReturnFocusToolButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReturnFocusToolButton *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->about_to_activate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReturnFocusToolButton::*)()>(_a, &ReturnFocusToolButton::about_to_activate, 0))
            return;
    }
}

const QMetaObject *octave::ReturnFocusToolButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::ReturnFocusToolButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave21ReturnFocusToolButtonE_t>.strings))
        return static_cast<void*>(this);
    return HoverToolButton::qt_metacast(_clname);
}

int octave::ReturnFocusToolButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = HoverToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void octave::ReturnFocusToolButton::about_to_activate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN6octave15ReturnFocusMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::ReturnFocusMenu::qt_create_metaobjectdata<qt_meta_tag_ZN6octave15ReturnFocusMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::ReturnFocusMenu",
        "about_to_activate",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'about_to_activate'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReturnFocusMenu, qt_meta_tag_ZN6octave15ReturnFocusMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::ReturnFocusMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15ReturnFocusMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15ReturnFocusMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave15ReturnFocusMenuE_t>.metaTypes,
    nullptr
} };

void octave::ReturnFocusMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReturnFocusMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->about_to_activate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReturnFocusMenu::*)()>(_a, &ReturnFocusMenu::about_to_activate, 0))
            return;
    }
}

const QMetaObject *octave::ReturnFocusMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::ReturnFocusMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15ReturnFocusMenuE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int octave::ReturnFocusMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void octave::ReturnFocusMenu::about_to_activate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN6octave15variable_editorE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::variable_editor::qt_create_metaobjectdata<qt_meta_tag_ZN6octave15variable_editorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::variable_editor",
        "updated",
        "",
        "finished",
        "command_signal",
        "cmd",
        "refresh_signal",
        "clear_content_signal",
        "copy_clipboard_signal",
        "paste_clipboard_signal",
        "level_up_signal",
        "save_signal",
        "delete_selected_signal",
        "interpreter_event",
        "fcn_callback",
        "fcn",
        "meth_callback",
        "meth",
        "callUpdate",
        "QModelIndex",
        "notice_settings",
        "edit_variable",
        "name",
        "octave_value",
        "val",
        "variable_destroyed",
        "obj",
        "variable_focused",
        "record_hovered_focus_variable",
        "restore_hovered_focus_variable",
        "closeEvent",
        "QCloseEvent*",
        "save",
        "cutClipboard",
        "copyClipboard",
        "pasteClipboard",
        "levelUp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'command_signal'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'refresh_signal'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clear_content_signal'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copy_clipboard_signal'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paste_clipboard_signal'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'level_up_signal'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'save_signal'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'delete_selected_signal'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const fcn_callback &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const meth_callback &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'callUpdate'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 }, { 0x80000000 | 19, 2 },
        }}),
        // Slot 'notice_settings'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'edit_variable'
        QtMocHelpers::SlotData<void(const QString &, const octave_value &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'variable_destroyed'
        QtMocHelpers::SlotData<void(QObject *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 26 },
        }}),
        // Slot 'variable_focused'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'record_hovered_focus_variable'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restore_hovered_focus_variable'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeEvent'
        QtMocHelpers::SlotData<void(QCloseEvent *)>(30, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 31, 2 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'cutClipboard'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'copyClipboard'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'pasteClipboard'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'levelUp'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<variable_editor, qt_meta_tag_ZN6octave15variable_editorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::variable_editor::staticMetaObject = { {
    QMetaObject::SuperData::link<octave_dock_widget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15variable_editorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15variable_editorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave15variable_editorE_t>.metaTypes,
    nullptr
} };

void octave::variable_editor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<variable_editor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updated(); break;
        case 1: _t->finished(); break;
        case 2: _t->command_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->refresh_signal(); break;
        case 4: _t->clear_content_signal(); break;
        case 5: _t->copy_clipboard_signal(); break;
        case 6: _t->paste_clipboard_signal(); break;
        case 7: _t->level_up_signal(); break;
        case 8: _t->save_signal(); break;
        case 9: _t->delete_selected_signal(); break;
        case 10: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
        case 11: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
        case 12: _t->callUpdate((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 13: _t->notice_settings(); break;
        case 14: _t->edit_variable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<octave_value>>(_a[2]))); break;
        case 15: _t->variable_destroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 16: _t->variable_focused((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->record_hovered_focus_variable(); break;
        case 18: _t->restore_hovered_focus_variable(); break;
        case 19: _t->closeEvent((*reinterpret_cast<std::add_pointer_t<QCloseEvent*>>(_a[1]))); break;
        case 20: _t->save(); break;
        case 21: _t->cutClipboard(); break;
        case 22: _t->copyClipboard(); break;
        case 23: _t->pasteClipboard(); break;
        case 24: _t->levelUp(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::updated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::finished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)(const QString & )>(_a, &variable_editor::command_signal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::refresh_signal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::clear_content_signal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::copy_clipboard_signal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::paste_clipboard_signal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::level_up_signal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::save_signal, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)()>(_a, &variable_editor::delete_selected_signal, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)(const fcn_callback & )>(_a, &variable_editor::interpreter_event, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (variable_editor::*)(const meth_callback & )>(_a, &variable_editor::interpreter_event, 11))
            return;
    }
}

const QMetaObject *octave::variable_editor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::variable_editor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave15variable_editorE_t>.strings))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::variable_editor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void octave::variable_editor::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::variable_editor::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void octave::variable_editor::command_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void octave::variable_editor::refresh_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void octave::variable_editor::clear_content_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void octave::variable_editor::copy_clipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void octave::variable_editor::paste_clipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void octave::variable_editor::level_up_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void octave::variable_editor::save_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void octave::variable_editor::delete_selected_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void octave::variable_editor::interpreter_event(const fcn_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void octave::variable_editor::interpreter_event(const meth_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
